@@ -9,7 +9,7 @@
 package Dist::Zilla::Plugin::Git::GatherDir;
 # ABSTRACT: Gather all tracked files in a Git working directory
 
-our $VERSION = '2.044';
+our $VERSION = '2.047';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::GatherDir' => { -version => 4.200016 }; # exclude_match
@@ -53,7 +53,7 @@ extends 'Dist::Zilla::Plugin::GatherDir' => { -version => 4.200016 }; # exclude_
 #pod =cut
 
 use List::Util 1.45 qw(uniq);
-use MooseX::Types::Moose qw(Bool);
+use Types::Standard 'Bool';
 
 use namespace::autoclean;
 
@@ -142,6 +142,11 @@ around dump_config => sub
         blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
+    foreach my $opt (qw(prune_directory follow_symlinks)) {
+      $self->log('WARNING: unused config variable "'.$opt.'"') if exists $config->{+__PACKAGE__}{$opt};
+      delete $config->{+__PACKAGE__}{$opt};
+    }
+
     return $config;
 };
 
@@ -156,8 +161,7 @@ override gather_files => sub {
   # Convert ~ portion to real directory:
   $root =~ s{^(~[^\\/]*)([\\/])}{$self->_homedir($1) . $2}e;
 
-  $root = Path::Tiny::path($root);
-  $root = $root->absolute($self->zilla->root->absolute);
+  $root = Path::Tiny::path($root)->absolute($self->zilla->root);
 
   # Prepare to gather files
   my $git = Git::Wrapper->new($root->stringify);
@@ -169,7 +173,7 @@ override gather_files => sub {
   $exclude_regex = qr/$exclude_regex|$_/
     for (@{ $self->exclude_match });
 
-  my %is_excluded = map {; $_ => 1 } @{ $self->exclude_filename };
+  my %is_excluded = map +($_ => 1), @{ $self->exclude_filename };
 
   my $prefix = $self->prefix;
 
@@ -182,7 +186,7 @@ override gather_files => sub {
 
     # Exclusion tests
     unless ($self->include_dotfiles) {
-      next if grep { /^\./ } split q{/}, $file->stringify;
+      next if grep /^\./, split q{/}, $file->stringify;
     }
 
     next if $file =~ $exclude_regex;
@@ -239,7 +243,7 @@ Dist::Zilla::Plugin::Git::GatherDir - Gather all tracked files in a Git working
 
 =head1 VERSION
 
-version 2.044
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -358,8 +362,6 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
